@@ -15,11 +15,7 @@
 #ifdef PURPOSE_FOUND
 #include <Purpose/AlternativesModel>
 #include <purpose_version.h>
-#if PURPOSE_VERSION >= QT_VERSION_CHECK(5, 104, 0)
 #include <Purpose/Menu>
-#else
-#include <PurposeWidgets/Menu>
-#endif
 #endif
 
 class ExportMenu : public SpectacleMenu
@@ -27,7 +23,7 @@ class ExportMenu : public SpectacleMenu
     Q_OBJECT
 
 public:
-    explicit ExportMenu(QWidget *parent = nullptr);
+    static ExportMenu *instance();
 
 public Q_SLOTS:
     void openPrintDialog();
@@ -36,7 +32,9 @@ Q_SIGNALS:
     void imageShared(int error, const QString &message);
 
 private:
-    Q_SLOT void onPixmapChanged();
+    explicit ExportMenu(QWidget *parent = nullptr);
+
+    Q_SLOT void onImageChanged();
     Q_SLOT void openScreenshotsFolder();
 
     void getKServiceItems();
@@ -46,8 +44,9 @@ private:
     void loadPurposeItems();
 
     bool mUpdatedImageAvailable;
-    Purpose::Menu *mPurposeMenu = nullptr;
+    std::unique_ptr<Purpose::Menu> mPurposeMenu;
 #endif
+    friend class ExportMenuSingleton;
 };
 
 #endif // EXPORTMENU_H
