@@ -34,6 +34,7 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KNotification>
+#include <KStatusNotifierItem>
 #include <KWindowSystem>
 #include <KX11Extras>
 #include <LayerShellQt/Shell>
@@ -48,6 +49,7 @@
 #include <QDrag>
 #include <QKeySequence>
 #include <QMimeData>
+#include <QMovie>
 #include <QProcess>
 #include <QQmlComponent>
 #include <QQmlContext>
@@ -63,7 +65,7 @@
 using namespace Qt::StringLiterals;
 
 SpectacleCore *SpectacleCore::s_self = nullptr;
-static std::unique_ptr<QSystemTrayIcon> s_systemTrayIcon;
+static std::unique_ptr<KStatusNotifierItem> s_systemTrayIcon;
 
 SpectacleCore::SpectacleCore(QObject *parent)
     : QObject(parent)
@@ -237,25 +239,69 @@ SpectacleCore::SpectacleCore(QObject *parent)
         onScreenshotOrRecordingFailed(message, uiMessage, &SpectacleCore::dbusScreenshotFailed, &ViewerWindow::showScreenshotFailedMessage);
     });
 
-    s_systemTrayIcon = std::make_unique<QSystemTrayIcon>(QIcon::fromTheme(u"media-record-symbolic"_s));
-    auto systemTrayIcon = s_systemTrayIcon.get();
-    connect(systemTrayIcon, &QSystemTrayIcon::activated, systemTrayIcon, [](auto reason) {
-        if (reason == QSystemTrayIcon::Trigger) {
-            SpectacleCore::instance()->finishRecording();
-        }
-    });
-
     auto videoPlatform = m_videoPlatform.get();
-    connect(videoPlatform, &VideoPlatform::recordingChanged,
-            systemTrayIcon, [this](bool isRecording){
-        s_systemTrayIcon->setVisible(isRecording);
-        if (!isRecording) {
+    connect(videoPlatform, &VideoPlatform::recordingChanged, this, [this](bool isRecording) {
+        if (isRecording) {
+            static const auto recordingIcon = u":/icons/256-status-media-recording.webp"_s;
+            static const auto recordingStartedIcon = u":/icons/256-status-media-recording-started.webp"_s;
+            static const auto recordingPulseIcon = u":/icons/256-status-media-recording-pulse.webp"_s;
+            s_systemTrayIcon = std::make_unique<KStatusNotifierItem>();
+            s_systemTrayIcon->setStatus(KStatusNotifierItem::Active);
+            s_systemTrayIcon->setCategory(KStatusNotifierItem::SystemServices);
+            s_systemTrayIcon->setToolTipTitle(i18nc("@info:tooltip title for recording tray icon", //
+                                                    "Spectacle is Recording"));
+            s_systemTrayIcon->setStandardActionsEnabled(false);
+            connect(s_systemTrayIcon.get(), &KStatusNotifierItem::activateRequested, this, [] {
+                SpectacleCore::instance()->finishRecording();
+            });
+            const auto messageTitle = i18nc("recording notification title", "Spectacle is Recording");
+            const auto messageBody = i18nc("recording notification message", "Click the system tray icon to finish recording");
+            s_systemTrayIcon->showMessage(messageTitle, messageBody, u"media-record"_s, 4000);
+            static const auto initPulseAnimation = [] {
+                auto animation = new QMovie(recordingPulseIcon, {}, s_systemTrayIcon.get());
+                animation->setCacheMode(QMovie::CacheAll);
+                connect(animation, &QMovie::frameChanged, animation, [animation] {
+                    s_systemTrayIcon->setIconByPixmap(animation->currentPixmap());
+                });
+                // We periodically switch to a static image instead of having a period in the
+                // animation where nothing happens to be a bit more efficient.
+                // NOTE: If QMovie::finished isn't working,
+                // you probably edited the icon and forgot to set the loop count.
+                connect(animation, &QMovie::finished, animation, [animation] {
+                    animation->stop();
+                    static const auto recordingPixmap = QPixmap{recordingIcon};
+                    s_systemTrayIcon->setIconByPixmap(recordingPixmap);
+                    const auto animationDuration = animation->nextFrameDelay() * animation->frameCount() / (animation->speed() / 100.0);
+                    QTimer::singleShot(animationDuration / 2, animation, &QMovie::start);
+                });
+                animation->start();
+            };
+            auto startedAnimation = new QMovie(recordingStartedIcon, {}, s_systemTrayIcon.get());
+            startedAnimation->setCacheMode(QMovie::CacheAll);
+            connect(startedAnimation, &QMovie::frameChanged, startedAnimation, [startedAnimation] {
+                s_systemTrayIcon->setIconByPixmap(startedAnimation->currentPixmap());
+            });
+            connect(startedAnimation, &QMovie::finished, startedAnimation, [startedAnimation] {
+                startedAnimation->stop();
+                startedAnimation->deleteLater();
+                initPulseAnimation();
+            });
+            startedAnimation->start();
+        } else {
+            s_systemTrayIcon.reset();
             m_captureWindows.clear();
         }
     });
     connect(videoPlatform, &VideoPlatform::recordedTimeChanged, this, [this] {
         Q_EMIT recordedTimeChanged();
-        s_systemTrayIcon->setToolTip(i18nc("@info:tooltip", "Spectacle is recording: %1\nClick to finish recording", recordedTime()));
+        if (!s_systemTrayIcon) {
+            return;
+        }
+        auto subtitle = i18nc("@info:tooltip subtitle for recording tray icon", //
+                              "Time recorded: %1\n" //
+                              "Click to finish recording",
+                              recordedTime());
+        s_systemTrayIcon->setToolTipSubTitle(subtitle);
     });
     connect(videoPlatform, &VideoPlatform::recordingSaved, this, [this](const QUrl &fileUrl) {
         // Always try to save. Needed to move recordings out of temp dir.
@@ -369,7 +415,6 @@ SpectacleCore::SpectacleCore(QObject *parent)
 
     connect(exportManager, &ExportManager::errorMessage, this, &SpectacleCore::showErrorMessage);
 
-    connect(imagePlatform, &ImagePlatform::windowTitleChanged, exportManager, &ExportManager::setWindowTitle);
     connect(m_annotationDocument.get(), &AnnotationDocument::repaintNeeded, m_annotationSyncTimer.get(), qOverload<>(&QTimer::start));
     connect(m_annotationSyncTimer.get(), &QTimer::timeout, this, [this] {
         ExportManager::instance()->setImage(m_annotationDocument->renderToImage());
@@ -768,9 +813,6 @@ void SpectacleCore::takeNewScreenshot(ImagePlatform::GrabMode grabMode, int time
         m_cliOptions[CommandLineOptions::EditExisting] = false;
     }
 
-    // Clear the window title that can be used in file names.
-    ExportManager::instance()->setWindowTitle({});
-
     m_delayAnimation->stop();
 
     m_lastGrabMode = grabMode;
